==> rapid_widgets_library-0.2.42.tar.gz: lib/custom-webDrawer.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

class NavigationDrawerWEB extends StatefulWidget {
  final DrawerParameters drawerParameters;

  NavigationDrawerWEB({this.drawerParameters});

  @override
  _NavigationDrawerState createState() => _NavigationDrawerState();
}

class _NavigationDrawerState extends State<NavigationDrawerWEB> {
  Widget buildHeader() {
    return (widget.drawerParameters.urlImage != 'null')
        ? Container(
      // padding: EdgeInsets.symmetric(vertical: 10),
        alignment: Alignment.center,
        child: Image(
          height: 80,
          width: 80,
          image: NetworkImage(widget.drawerParameters.urlImage),
        ))
        : SizedBox.shrink();
  }

  Widget buildMenuItem({String text, IconData icon, Color iconTextColor}) {
    final hoverColor = Colors.grey[300];
    return (text != 'null' || icon != null)
        ? (icon != null)
        ? ListTile(
      leading: Icon(icon, color: iconTextColor ?? Colors.black),
      title: (text != 'null')
          ? Text(text, style: TextStyle(color: iconTextColor ?? Colors.black))
          : SizedBox.shrink(),
      hoverColor: hoverColor,
      onTap: () {},
    )
        : ListTile(
      title: (text != 'null')
          ? Text(text, style: TextStyle(color: iconTextColor ?? Colors.black))
          : SizedBox.shrink(),
      hoverColor: hoverColor,
      onTap: () {},
    )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      color: widget.drawerParameters.drawerColor,
      child: Column(children: [
        buildHeader(),
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            for (int i = 0; i < widget.drawerParameters.items.length; i++)
              for (var key in widget.drawerParameters.items[i].keys)
                if (key != 'null' || widget.drawerParameters.items[i][key] != null)
                  Padding(
                    padding: const EdgeInsets.only(left: 10, top: 3, bottom: 3),
                    child: TranslateOnHover(
                      icon: widget.drawerParameters.items[i][key],
                      text: key,
                      iconTextColor: widget.drawerParameters.iconTextColor,
                    ),
                  )
          ],
        ),
      ]),
    );
  }
}

class TranslateOnHover extends StatefulWidget {
  final Widget child;
  final String text;
  final IconData icon;
  final Color iconTextColor;

  TranslateOnHover({this.child, this.iconTextColor, this.icon, this.text});

  @override
  _TranslateOnHoverState createState() => _TranslateOnHoverState();
}

class _TranslateOnHoverState extends State<TranslateOnHover> {
  final nonHoverTransform = Matrix4.identity();
  final hoverTransform = Matrix4.identity()
    ..translate(0, -5, 0)
    ..scale(1.1);

  bool _hovering = false;

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
        onEnter: (e) => _mouseEnter(true),
        onExit: (e) => _mouseEnter(false),
        child: AnimatedContainer(
          duration: const Duration(milliseconds: 200),
          child: (widget.icon != null)
              ? Row(
            children: [
              (widget.icon != null)
                  ? Icon(
                widget.icon,
                color: widget.iconTextColor ?? Colors.black,
              )
                  : SizedBox.shrink(),
              (widget.icon != null)
                  ? SizedBox(
                width: 4,
              )
                  : SizedBox.shrink(),
              (widget.text != 'null')
                  ? Text(
                widget.text,
                style: TextStyle(color: widget.iconTextColor ?? Colors.black),
              )
                  : SizedBox()
            ],
          )
              : Row(
            children: [
              (widget.text != 'null')
                  ? Text(
                widget.text,
                style: TextStyle(color: widget.iconTextColor ?? Colors.black),
              )
                  : SizedBox()
            ],
          ),
          /* :SizedBox.shrink(),*/

          transform: _hovering ? hoverTransform : nonHoverTransform,
        ));
  }

  void _mouseEnter(bool hovering) {
    setState(() {
      _hovering = hovering;
    });
  }
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-webDrawer.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';

class NavigationDrawerWEB extends StatefulWidget {
  final DrawerParameters drawerParameters;

  NavigationDrawerWEB({this.drawerParameters});

  @override
  _NavigationDrawerState createState() => _NavigationDrawerState();
}

class _NavigationDrawerState extends State<NavigationDrawerWEB> {
  Widget buildHeader() {
    return (widget.drawerParameters.urlImage != 'null')
        ? Container(
      // padding: EdgeInsets.symmetric(vertical: 10),
        alignment: Alignment.center,
        child: Image(
          height: 80,
          width: 80,
          image: NetworkImage(widget.drawerParameters.urlImage),
        ))
        : SizedBox.shrink();
  }

  Widget buildMenuItem({String text, IconData icon, Color iconTextColor}) {
    final hoverColor = Colors.grey[300];
    return (text != 'null' || icon != null)
        ? (icon != null)
        ? ListTile(
      leading: Icon(icon, color: iconTextColor ?? Colors.black),
      title: (text != 'null')
          ? Text(text, style: GoogleFonts.getFont('Roboto',color: iconTextColor ?? Colors.black))
          : SizedBox.shrink(),
      hoverColor: hoverColor,
      onTap: () {},
    )
        : ListTile(
      title: (text != 'null')
          ? Text(text, style: GoogleFonts.getFont('Roboto',color: iconTextColor ?? Colors.black))
          : SizedBox.shrink(),
      hoverColor: hoverColor,
      onTap: () {},
    )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      color: widget.drawerParameters.drawerColor,
      child: Column(children: [
        buildHeader(),
        Row(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            for (int i = 0; i < widget.drawerParameters.items.length; i++)
              for (var key in widget.drawerParameters.items[i].keys)
                if (key != 'null' || widget.drawerParameters.items[i][key] != null)
                  Padding(
                    padding: const EdgeInsets.only(left: 10, top: 3, bottom: 3),
                    child: TranslateOnHover(
                      icon: widget.drawerParameters.items[i][key],
                      text: key,
                      iconTextColor: widget.drawerParameters.iconTextColor,
                    ),
                  )
          ],
        ),
      ]),
    );
  }
}

class TranslateOnHover extends StatefulWidget {
  final Widget child;
  final String text;
  final IconData icon;
  final Color iconTextColor;

  TranslateOnHover({this.child, this.iconTextColor, this.icon, this.text});

  @override
  _TranslateOnHoverState createState() => _TranslateOnHoverState();
}

class _TranslateOnHoverState extends State<TranslateOnHover> {
  final nonHoverTransform = Matrix4.identity();
  final hoverTransform = Matrix4.identity()
    ..translate(0, -5, 0)
    ..scale(1.1);

  bool _hovering = false;

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
        onEnter: (e) => _mouseEnter(true),
        onExit: (e) => _mouseEnter(false),
        child: AnimatedContainer(
          duration: const Duration(milliseconds: 200),
          child: (widget.icon != null)
              ? Row(
            children: [
              (widget.icon != null)
                  ? Icon(
                widget.icon,
                color: widget.iconTextColor ?? Colors.black,
              )
                  : SizedBox.shrink(),
              (widget.icon != null)
                  ? SizedBox(
                width: 4,
              )
                  : SizedBox.shrink(),
              (widget.text != 'null')
                  ? Text(
                widget.text,
                style: GoogleFonts.getFont('Roboto',color: widget.iconTextColor ?? Colors.black),
              )
                  : SizedBox()
            ],
          )
              : Row(
            children: [
              (widget.text != 'null')
                  ? Text(
                widget.text,
                style: GoogleFonts.getFont('Roboto',color: widget.iconTextColor ?? Colors.black),
              )
                  : SizedBox()
            ],
          ),
          /* :SizedBox.shrink(),*/

          transform: _hovering ? hoverTransform : nonHoverTransform,
        ));
  }

  void _mouseEnter(bool hovering) {
    setState(() {
      _hovering = hovering;
    });
  }
}
